import SecurityInterface
from PyObjCTools.TestSupport import TestCase


class TestSFAuthorizationPluginView(TestCase):
    def test_constants(self):
        self.assertEqual(
            SecurityInterface.SFButtonTypeCancel, SecurityInterface.NSCancelButton
        )
        self.assertEqual(SecurityInterface.SFButtonTypeOK, SecurityInterface.NSOKButton)
        self.assertEqual(
            SecurityInterface.SFButtonTypeBack, SecurityInterface.SFButtonTypeCancel
        )
        self.assertEqual(
            SecurityInterface.SFButtonTypeLogin, SecurityInterface.SFButtonTypeOK
        )

        self.assertEqual(SecurityInterface.SFViewTypeIdentityAndCredentials, 0)
        self.assertEqual(SecurityInterface.SFViewTypeCredentials, 1)

        self.assertIsInstance(
            SecurityInterface.SFAuthorizationPluginViewUserNameKey, str
        )
        self.assertIsInstance(
            SecurityInterface.SFAuthorizationPluginViewUserShortNameKey, str
        )
        self.assertIsInstance(SecurityInterface.SFDisplayViewException, str)

    def test_classes(self):
        SecurityInterface.SFAuthorizationPluginView

    def test_methods(self):
        # XXX: initWithCallbacks_andEngineRef_: needs tests that exercise this,
        #      after binding Security framework...

        self.assertArgIsBOOL(SecurityInterface.SFAuthorizationPluginView.setEnabled_, 0)
        self.assertArgIsBOOL(
            SecurityInterface.SFAuthorizationPluginView.setButton_enabled_, 1
        )



import SecurityInterface
from PyObjCTools.TestSupport import TestCase
import objc


class TestSFCertificateTrustPanel(TestCase):
    def test_classes(self):
        SecurityInterface.SFCertificateTrustPanel

    def test_methods(self):
        self.assertArgIsSEL(
            SecurityInterface.SFCertificateTrustPanel.beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_trust_message_,
            2,
            b"v@:@" + objc._C_NSInteger + b"^v",
        )



import SecurityInterface
from PyObjCTools.TestSupport import TestCase, expectedFailure


class TestSFCertificateView(TestCase):
    @expectedFailure
    def test_constants(self):
        # Constant is not present on 10.12
        self.assertHasAttr(
            SecurityInterface, "SFCertificateViewDisclosureStateDidChange"
        )
        self.assertIsInstance(
            SecurityInterface.SFCertificateViewDisclosureStateDidChange, str
        )

    def test_classes(self):
        SecurityInterface.SFCertificateView

    def test_methods(self):
        self.assertArgIsBOOL(SecurityInterface.SFCertificateView.setEditableTrust_, 0)
        self.assertResultIsBOOL(SecurityInterface.SFCertificateView.isEditable)
        self.assertArgIsBOOL(SecurityInterface.SFCertificateView.setDisplayTrust_, 0)
        self.assertResultIsBOOL(SecurityInterface.SFCertificateView.isTrustDisplayed)
        self.assertArgIsBOOL(SecurityInterface.SFCertificateView.setDisplayDetails_, 0)
        self.assertResultIsBOOL(SecurityInterface.SFCertificateView.detailsDisplayed)
        self.assertArgIsBOOL(
            SecurityInterface.SFCertificateView.setDetailsDisclosed_, 0
        )
        self.assertResultIsBOOL(SecurityInterface.SFCertificateView.detailsDisclosed)
        self.assertArgIsBOOL(
            SecurityInterface.SFCertificateView.setPoliciesDisclosed_, 0
        )
        self.assertResultIsBOOL(SecurityInterface.SFCertificateView.policiesDisclosed)



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 19:21:51 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$SFAuthorizationPluginViewUserNameKey$SFAuthorizationPluginViewUserShortNameKey$SFCertificateViewDisclosureStateDidChange$SFDisplayViewException$"""
enums = """$SFAuthorizationStartupState@0$SFAuthorizationViewInProgressState@2$SFAuthorizationViewLockedState@1$SFAuthorizationViewUnlockedState@3$SFButtonTypeBack@0$SFButtonTypeCancel@0$SFButtonTypeLogin@1$SFButtonTypeOK@1$SFViewTypeCredentials@1$SFViewTypeIdentityAndCredentials@0$"""
misc.update({})
misc.update({})
aliases = {
    "SFButtonTypeBack": "SFButtonTypeCancel",
    "SFButtonTypeLogin": "SFButtonTypeOK",
    "SFButtonTypeOK": "NSOKButton",
    "SFButtonTypeCancel": "NSCancelButton",
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"authorizationViewCreatedAuthorization:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"authorizationViewDidAuthorize:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"authorizationViewDidDeauthorize:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"authorizationViewDidHide:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"authorizationViewReleasedAuthorization:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"authorizationViewShouldDeauthorize:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"certificatePanelShowHelp:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"chooseIdentityPanelShowHelp:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"SFAuthorizationPluginView",
        b"setButton:enabled:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(b"SFAuthorizationPluginView", b"setEnabled:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SFAuthorizationView",
        b"authorizationRights",
        {"retval": {"type": b"^{_AuthorizationRights=I^{_AuthorizationItem=^cQ^vI}}"}},
    )
    r(b"SFAuthorizationView", b"authorize:", {"retval": {"type": b"Z"}})
    r(b"SFAuthorizationView", b"deauthorize:", {"retval": {"type": b"Z"}})
    r(b"SFAuthorizationView", b"isEnabled", {"retval": {"type": b"Z"}})
    r(
        b"SFAuthorizationView",
        b"setAuthorizationRights:",
        {
            "arguments": {
                2: {"type": b"^{_AuthorizationRights=I^{_AuthorizationItem=^cQ^vI}}"}
            }
        },
    )
    r(b"SFAuthorizationView", b"setAutoupdate:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SFAuthorizationView",
        b"setAutoupdate:interval:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"SFAuthorizationView", b"setEnabled:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SFAuthorizationView", b"updateStatus:", {"retval": {"type": b"Z"}})
    r(
        b"SFCertificatePanel",
        b"beginSheetForWindow:modalDelegate:didEndSelector:contextInfo:certificates:showGroup:",
        {
            "arguments": {
                4: {"sel_of_type": sel32or64(b"v@:@i^v", b"v@:@q^v")},
                7: {"type": b"Z"},
            }
        },
    )
    r(
        b"SFCertificatePanel",
        b"beginSheetForWindow:modalDelegate:didEndSelector:contextInfo:trust:showGroup:",
        {
            "arguments": {
                4: {"sel_of_type": sel32or64(b"v@:@i^v", b"v@:@q^v")},
                7: {"type": b"Z"},
            }
        },
    )
    r(
        b"SFCertificatePanel",
        b"runModalForCertificates:showGroup:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(
        b"SFCertificatePanel",
        b"runModalForTrust:showGroup:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(b"SFCertificatePanel", b"setShowsHelp:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SFCertificatePanel", b"showsHelp", {"retval": {"type": b"Z"}})
    r(
        b"SFCertificateTrustPanel",
        b"beginSheetForWindow:modalDelegate:didEndSelector:contextInfo:trust:message:",
        {"arguments": {4: {"sel_of_type": sel32or64(b"v@:@i^v", b"v@:@q^v")}}},
    )
    r(b"SFCertificateView", b"detailsDisclosed", {"retval": {"type": b"Z"}})
    r(b"SFCertificateView", b"detailsDisplayed", {"retval": {"type": b"Z"}})
    r(b"SFCertificateView", b"isEditable", {"retval": {"type": b"Z"}})
    r(b"SFCertificateView", b"isTrustDisplayed", {"retval": {"type": b"Z"}})
    r(b"SFCertificateView", b"policiesDisclosed", {"retval": {"type": b"Z"}})
    r(b"SFCertificateView", b"setDetailsDisclosed:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SFCertificateView", b"setDisplayDetails:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SFCertificateView", b"setDisplayTrust:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SFCertificateView", b"setEditableTrust:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"SFCertificateView",
        b"setPoliciesDisclosed:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"SFChooseIdentityPanel",
        b"beginSheetForWindow:modalDelegate:didEndSelector:contextInfo:identities:message:",
        {"arguments": {4: {"sel_of_type": sel32or64(b"v@:@i^v", b"v@:@q^v")}}},
    )
    r(b"SFChooseIdentityPanel", b"setShowsHelp:", {"arguments": {2: {"type": b"Z"}}})
    r(b"SFChooseIdentityPanel", b"showsHelp", {"retval": {"type": b"Z"}})
    r(
        b"SFKeychainSavePanel",
        b"beginSheetForDirectory:file:modalForWindow:modalDelegate:didEndSelector:contextInfo:",
        {"arguments": {6: {"sel_of_type": sel32or64(b"v@:@i^v", b"v@:@q^v")}}},
    )
    r(
        b"SFKeychainSettingsPanel",
        b"beginSheetForWindow:modalDelegate:didEndSelector:contextInfo:settings:keychain:",
        {
            "arguments": {
                4: {"sel_of_type": sel32or64(b"v@:@i^v", b"v@:@q^v")},
                6: {"type": b"^{SecKeychainSettings=IZZI}"},
            }
        },
    )
    r(
        b"SFKeychainSettingsPanel",
        b"runModalForSettings:keychain:",
        {"arguments": {2: {"type": b"^{SecKeychainSettings=IZZI}"}}},
    )
    r(b"null", b"authorizationViewShouldDeauthorize:", {"retval": {"type": b"Z"}})
    r(b"null", b"certificatePanelShowHelp:", {"retval": {"type": b"Z"}})
    r(b"null", b"chooseIdentityPanelShowHelp:", {"retval": {"type": b"Z"}})
    r(b"null", b"setButton:enabled:", {"arguments": {3: {"type": b"Z"}}})
finally:
    objc._updatingMetadata(False)
protocols = {
    "SFChooseIdentityPanelDelegate": objc.informal_protocol(
        "SFChooseIdentityPanelDelegate",
        [
            objc.selector(
                None, b"chooseIdentityPanelShowHelp:", b"Z@:@", isRequired=False
            )
        ],
    ),
    "SFCertificatePanelDelegate": objc.informal_protocol(
        "SFCertificatePanelDelegate",
        [objc.selector(None, b"certificatePanelShowHelp:", b"Z@:@", isRequired=False)],
    ),
    "SFAuthorizationViewDelegate": objc.informal_protocol(
        "SFAuthorizationViewDelegate",
        [
            objc.selector(
                None,
                b"authorizationViewCreatedAuthorization:",
                b"v@:@",
                isRequired=False,
            ),
            objc.selector(
                None, b"authorizationViewDidHide:", b"v@:@", isRequired=False
            ),
            objc.selector(
                None, b"authorizationViewDidAuthorize:", b"v@:@", isRequired=False
            ),
            objc.selector(
                None, b"authorizationViewDidDeauthorize:", b"v@:@", isRequired=False
            ),
            objc.selector(
                None, b"authorizationViewShouldDeauthorize:", b"Z@:@", isRequired=False
            ),
            objc.selector(
                None,
                b"authorizationViewReleasedAuthorization:",
                b"v@:@",
                isRequired=False,
            ),
        ],
    ),
}
expressions = {}

# END OF FILE



"""
Python mapping for the SecurityInterface framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import AppKit
import objc
import Security
from SecurityInterface import _metadata
from SecurityInterface import _SecurityInterface

sys.modules["SecurityInterface"] = mod = objc.ObjCLazyModule(
    "SecurityInterface",
    "com.apple.securityinterface",
    objc.pathForFramework("/System/Library/Frameworks/SecurityInterface.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_SecurityInterface, AppKit, Security),
)


del sys.modules["SecurityInterface._metadata"]



import SecurityInterface
from PyObjCTools.TestSupport import TestCase
import objc


class TestSFCertificatePanelHelper(SecurityInterface.NSObject):
    def certificatePanelShowHelp_(self, v):
        return 1


class TestSFCertificatePanel(TestCase):
    def test_classes(self):
        SecurityInterface.SFCertificatePanel

    def test_methods(self):
        self.assertArgIsBOOL(
            SecurityInterface.SFCertificatePanel.runModalForTrust_showGroup_, 1
        )
        self.assertArgIsBOOL(
            SecurityInterface.SFCertificatePanel.runModalForCertificates_showGroup_, 1
        )

        self.assertArgIsSEL(
            SecurityInterface.SFCertificatePanel.beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_trust_showGroup_,
            2,
            b"v@:@" + objc._C_NSInteger + b"^v",
        )
        self.assertArgIsBOOL(
            SecurityInterface.SFCertificatePanel.beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_trust_showGroup_,
            5,
        )

        self.assertArgIsSEL(
            SecurityInterface.SFCertificatePanel.beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_certificates_showGroup_,  # noqa: B950
            2,
            b"v@:@" + objc._C_NSInteger + b"^v",
        )
        self.assertArgIsBOOL(
            SecurityInterface.SFCertificatePanel.beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_certificates_showGroup_,  # noqa: B950
            5,
        )

        self.assertArgIsBOOL(SecurityInterface.SFCertificatePanel.setShowsHelp_, 0)
        self.assertResultIsBOOL(SecurityInterface.SFCertificatePanel.showsHelp)

        self.assertResultIsBOOL(TestSFCertificatePanelHelper.certificatePanelShowHelp_)



import SecurityInterface
from PyObjCTools.TestSupport import TestCase
import objc


class TestSFKeychainSettingsPanel(TestCase):
    def test_classes(self):
        SecurityInterface.SFKeychainSettingsPanel

    def test_methods(self):
        self.assertArgIsSEL(
            SecurityInterface.SFKeychainSettingsPanel.beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_settings_keychain_,  # noqa: B950
            2,
            b"v@:@" + objc._C_NSInteger + b"^v",
        )



import SecurityInterface
from PyObjCTools.TestSupport import TestCase
import objc


class TestSFKeychainSavePanel(TestCase):
    def test_classes(self):
        SecurityInterface.SFKeychainSavePanel

    def test_methods(self):
        self.assertArgIsSEL(
            SecurityInterface.SFKeychainSavePanel.beginSheetForDirectory_file_modalForWindow_modalDelegate_didEndSelector_contextInfo_,  # noqa: B950
            4,
            b"v@:@" + objc._C_NSInteger + b"^v",
        )



import SecurityInterface
from PyObjCTools.TestSupport import TestCase


class TestSFAuthorizationViewHelper(SecurityInterface.NSObject):
    def authorizationViewShouldDeauthorize_(self, v):
        return 1


class TestSFAuthorizationView(TestCase):
    def test_constants(self):
        self.assertEqual(SecurityInterface.SFAuthorizationStartupState, 0)
        self.assertEqual(SecurityInterface.SFAuthorizationViewLockedState, 1)
        self.assertEqual(SecurityInterface.SFAuthorizationViewInProgressState, 2)
        self.assertEqual(SecurityInterface.SFAuthorizationViewUnlockedState, 3)

    def test_classes(self):
        SecurityInterface.SFAuthorizationView

    def test_methods(self):
        self.assertResultIsBOOL(SecurityInterface.SFAuthorizationView.updateStatus_)
        self.assertArgIsBOOL(SecurityInterface.SFAuthorizationView.setAutoupdate_, 0)
        self.assertArgIsBOOL(
            SecurityInterface.SFAuthorizationView.setAutoupdate_interval_, 0
        )
        self.assertArgIsBOOL(SecurityInterface.SFAuthorizationView.setEnabled_, 0)
        self.assertResultIsBOOL(SecurityInterface.SFAuthorizationView.isEnabled)
        self.assertResultIsBOOL(SecurityInterface.SFAuthorizationView.authorize_)
        self.assertResultIsBOOL(SecurityInterface.SFAuthorizationView.deauthorize_)

        self.assertResultIsBOOL(
            TestSFAuthorizationViewHelper.authorizationViewShouldDeauthorize_
        )



import SecurityInterface
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestSFChooseIdentityTableCellView(TestCase):
    @min_os_level("10.13")
    def test_classes(self):
        SecurityInterface.SFChooseIdentityTableCellView



import SecurityInterface
from PyObjCTools.TestSupport import TestCase
import objc


class TestSFChooseIdentityPanelHelper(SecurityInterface.NSObject):
    def chooseIdentityPanelShowHelp_(self, v):
        return 1


class TestSFChooseIdentityPanel(TestCase):
    def test_classes(self):
        SecurityInterface.SFChooseIdentityPanel

    def test_methods(self):
        self.assertArgIsSEL(
            SecurityInterface.SFChooseIdentityPanel.beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_identities_message_,  # noqa: B950
            2,
            b"v@:@" + objc._C_NSInteger + b"^v",
        )

        self.assertArgIsBOOL(SecurityInterface.SFChooseIdentityPanel.setShowsHelp_, 0)
        self.assertResultIsBOOL(SecurityInterface.SFChooseIdentityPanel.showsHelp)

        self.assertResultIsBOOL(
            TestSFChooseIdentityPanelHelper.chooseIdentityPanelShowHelp_
        )
